// CORS when consuming Medusa from admin
const ADMIN_CORS =
  process.env.ADMIN_CORS ||
  "http://yunjiuding.com:7000,https://yunjiuding.com:7000,https://admin.yunjiuding.com,https://admin.yunjiuding.test,http://localhost:7000";

// CORS to avoid issues when consuming Medusa from a client
const STORE_CORS =
  process.env.STORE_CORS ||
  "http://yunjiuding.com:8000,https://yunjiuding.com:8000,http://localhost:8000,https://yunjiuding.test,https://yunjiuding.com,http://localhost:7000";

const storeURL = process.env.STORE_URL || "http://localhost:8000/";
// Database URL (here we use a local database called medusa-development)

const DATABASE_URL =
  process.env.DATABASE_URL ||
  "postgres://postgres:postgres@localhost:5432/medusa-docker";

// Medusa uses Redis, so this needs configuration as well
const REDIS_URL = process.env.REDIS_URL || "redis://:secret@localhost:6379";
const ASE_KEY = process.env.ASE_KEY || "e4ea89835ad64eb1b8d76069e33908d4"; //加密密钥
var ASE_IV = process.env.ASE_IV || "ff465fdecc764337"; //加密aesIV，偏移量

// Contentful Variables
const CONTENTFUL_SPACE_ID = process.env.CONTENTFUL_SPACE_ID || "";
const CONTENTFUL_ACCESS_TOKEN = process.env.CONTENTFUL_ACCESS_TOKEN || "";
const CONTENTFUL_ENV = process.env.CONTENTFUL_ENV || "";

// WECHAT PAY
const MCHID = "商户号";
const APPID = "公众号ID";
const PARTNER_KEY = "";
const PFX = "";
const notify_url = "";

// ALIPAY
const ALIPAY_APP_ID = process.env.ALIPAY_APP_ID || "";
const ALIPAY_GATEWAY = process.env.ALIPAY_GATEWAY || "";
const ALIPAY_PUBLIC_KEY = process.env.ALIPAY_PUBLIC_KEY || "";
const ALIPAY_PRIVATE_KEY = process.env.ALIPAY_PRIVATE_KEY || "";
const ALIPAY_RETURN_URL = process.env.ALIPAY_RETURN_URL || "";
const ALIPAY_NOTIFY_URL = process.env.ALIPAY_NOTIFY_URL || "";

// ALI-OSS
const OSS_URL = process.env.OSS_URL || "";
const BUCKET = process.env.BUCKET || "";
const REGION = process.env.REGION || "";
const ACCESS_KEY_ID = process.env.ACCESS_KEY_ID || "";
const SECRET_ACCESS_KEY = process.env.SECRET_ACCESS_KEY || "";

// This is the place to include plugins. See API documentation for a thorough guide on plugins.
const plugins = [
  `medusa-fulfillment-manual`,
  `medusa-payment-manual`,
  {
    resolve: `medusa-plugin-alipay`,
    options: {
      appId: ALIPAY_APP_ID,
      alipayPublicKey: ALIPAY_PUBLIC_KEY,
      privateKey: ALIPAY_PRIVATE_KEY,
      gateway: ALIPAY_GATEWAY,
      returnUrl: ALIPAY_RETURN_URL,
      notifyUrl: ALIPAY_NOTIFY_URL,
    },
  },
  {
    resolve: `medusa-alipay`,
    options: {
      appId: ALIPAY_APP_ID,
      alipayPublicKey: ALIPAY_PUBLIC_KEY,
      privateKey: ALIPAY_PRIVATE_KEY,
      gateway: ALIPAY_GATEWAY,
      returnUrl: ALIPAY_RETURN_URL,
      notifyUrl: ALIPAY_NOTIFY_URL,
    },
  },

  {
    resolve: `medusa-plugin-contentful`,
    options: {
      space_id: CONTENTFUL_SPACE_ID,
      access_token: CONTENTFUL_ACCESS_TOKEN,
      environment: CONTENTFUL_ENV,
    },
  },
  {
    resolve: `medusa-ali-oss`,
    options: {
      oss_url: OSS_URL,
      bucket: BUCKET,
      region: REGION,
      access_key_id: ACCESS_KEY_ID,
      secret_access_key: SECRET_ACCESS_KEY,
      storeURL: storeURL,
    },
  },
];

module.exports = {
  projectConfig: {
    redis_url: REDIS_URL,
    database_url: DATABASE_URL,
    database_type: "postgres",
    storeURL: storeURL,
    store_cors: STORE_CORS,
    admin_cors: ADMIN_CORS,
    ase_key: ASE_KEY,
  },
  plugins,
};
